[dts] [PATCH]tests: correct test case name

Peng Yuan yuan.peng at intel.com
Tue Jun 4 10:02:37 CEST 2019


Correct the name of test case.

Signed-off-by: Peng Yuan <yuan.peng at intel.com>

diff --git a/tests/TestSuite_unit_tests_crc.py b/tests/TestSuite_unit_tests_crc.py
index 2230ebf..334a651 100644
--- a/tests/TestSuite_unit_tests_crc.py
+++ b/tests/TestSuite_unit_tests_crc.py
@@ -32,7 +32,7 @@
 """
 DPDK Test suite.
 
-Cmdline autotest
+Crc autotest
 
 """
 
@@ -65,9 +65,9 @@ class TestUnitTestsCrc(TestCase):
         """
         pass
 
-    def test_cmdline(self):
+    def test_crc(self):
         """
         Run cmdline autotests in RTE command line.
         """
 
         self.dut.send_expect("./%s/app/test -n 1 -c %s" % (self.target, self.coremask), "R.*T.*E.*>.*>", 60)
@@ -65,9 +65,9 @@ class TestUnitTestsCrc(TestCase):
         """
-        Run cmdline autotests in RTE command line.
+        Run crc autotests in RTE command line.
         """
 
-- 
2.7.4



More information about the dts mailing list